@@ -2,7 +2,7 @@ package Finance::Nadex;
 
 use strict;
 use warnings;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use LWP::UserAgent;
 use JSON;
@@ -108,10 +108,10 @@ sub create_order {
     
     my $contract = $self->get_contract( epic => $args{epic} );
     
-    croak "ERROR: Finance::Nadex::create_order(): named argument 'price' is not valid\n"     unless $self->_is_valid_price($args{price}, $contract->type);
-    croak "ERROR: Finance::Nadex::create_order(): named argument 'direction' is not valid\n" unless $self->_is_valid_direction($args{direction});
-    croak "ERROR: Finance::Nadex::create_order(): named argument 'epic' is not valid\n"      unless $contract;
-    croak "ERROR: Finance::Nadex::create_order(): named argument 'size' is not valid\n"      unless $self->_is_valid_size($args{size});
+    croak "ERROR: Finance::Nadex::create_order(): named argument 'price' (->$args{price}<-) is not valid\n"     unless $self->_is_valid_price($args{price}, $contract->type);
+    croak "ERROR: Finance::Nadex::create_order(): named argument 'direction' (->$args{direction}<-) is not valid\n" unless $self->_is_valid_direction($args{direction});
+    croak "ERROR: Finance::Nadex::create_order(): named argument 'epic' (->$args{epic}<-) is not valid\n"      unless $contract;
+    croak "ERROR: Finance::Nadex::create_order(): named argument 'size' (->$args{size}<-) is not valid\n"      unless $self->_is_valid_size($args{size});
  
     # the market accepts only + or - for the direction; this enables the aliases 'buy' and 'sell'
     $args{direction} = '+' if $args{direction} eq 'buy';
@@ -119,7 +119,7 @@ sub create_order {
 
     # the price is dollars and cents for binaries and some instrument level
     # for spreads; only format the price to a currency if the order type is 'binary'
-    $args{price} = sprintf( "%.2f", $args{price} ) unless $contract->type eq 'spread';
+    $args{price} = sprintf( "%.2f", $args{price} ) if $contract->type eq 'binary';
 
     my $order_content = qq~
     {
@@ -152,7 +152,7 @@ sub get_contract {
     croak "ERROR: Finance::Nadex::get_contracts(): must be logged in\n" unless $self->logged_in;
     
     croak "ERROR: Finance::Nadex::get_contract(): must specify a named argument 'epic'\n" unless exists $args{epic};
-    croak "ERROR: Finance::Nadex::get_contract(): specified 'epic' is not valid\n"        unless $args{epic};
+    croak "ERROR: Finance::Nadex::get_contract(): specified 'epic' (->$args{epic}<-) is not valid\n"        unless $args{epic};
     
 	  my $epic_url = EPIC_URL.'/'.$args{epic};
     my $epic_ref = $self->_get($epic_url);
@@ -742,7 +742,7 @@ sub _is_valid_price {
         return 0 if $price !~ /^(\d+\.\d{1,2}|\.\d{1,2}|\d+)$/;
 
         if ($price =~ /\.(\d+)/) {
-            return 0 if $1 != 50 && $1 != 0;
+            return 0 if $1 != 0 && $1 != 25 && $1 != 50 && $1 != 75;
         }
     }
     
@@ -784,7 +784,7 @@ Finance::Nadex - Interact with the North American Derivatives Exchange
 
 =head1 VERSION
 
-Version 0.01
+Version 0.03
 
 =head1 SYNOPSIS
 
